@@ -30,6 +30,12 @@
 /* Define to enable tcp forwarding */
 #undef WITH_TCP_FORWARD
 
+/* For Ipv6 support */
+#undef WITH_IPV6
+
+/* For utmp support */
+#undef WITH_UTMP
+
 /* Define to indicate that shutdown seems to work properly */
 #undef SHUTDOWN_WORKS_WITH_UNIX_SOCKETS
 
@@ -39,6 +45,9 @@
 /* Define if the compiler understands __FUNCTION__ */
 #undef HAVE_GCC_FUNCTION
 
+/* Define if the compiler understands offsetof(TYPE, MEMBER) */
+#undef HAVE_C_OFFSETOF
+
 /* Define if a we have working UNIX98 pty handling */
 #undef HAVE_UNIX98_PTYS
 
