@@ -84,6 +84,11 @@
 
        ; Cleanup
        (resources object resource_list)
+
+       ; Connected peer
+       ; FIXME: Perhaps this should be a sockaddr or some other object
+       ; that facilitates reverse lookups?
+       (peer object address_info);
        
        ; Receiving
        (rec_max_packet simple UINT32)
@@ -141,7 +146,8 @@
 #define C_WRITE(c, s) A_WRITE((c)->write, (s) )
 
 struct ssh_connection *
-make_ssh_connection(const char *id_comment,
+make_ssh_connection(struct address_info *peer,
+		    const char *id_comment,
 		    struct command_continuation *c,
 		    struct exception_handler *e);
 
@@ -154,9 +160,6 @@ void connection_init_io(struct ssh_connection *connection,
 			struct abstract_write *raw,
 			struct randomness *r);
 
-struct packet_handler *make_fail_handler(void);
-struct packet_handler *make_unimplemented_handler(void);  
-
 /* Serialization */
 void connection_lock(struct ssh_connection *self);
 void connection_unlock(struct ssh_connection *self);
