@@ -1,6 +1,6 @@
 /* disconnect.c
  *
- * $Id: disconnect.c,v 1.17 2000/04/21 22:29:36 nisse Exp $ */
+ * $Id: disconnect.c,v 1.18 2000/04/23 17:48:48 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -48,7 +48,7 @@ do_disconnect(struct packet_handler *closure UNUSED,
   unsigned msg_number;
   UINT32 length;
   UINT32 reason;
-  UINT8 *msg;
+  const UINT8 *msg;
   
   static const struct exception disconnect_exception =
     STATIC_EXCEPTION(EXC_FINISH_IO, "Received disconnect message.");
