@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.54 2000/02/07 20:53:50 nisse Exp $ */
+ * $Id: io.h,v 1.59 2000/04/21 22:29:38 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -113,7 +113,7 @@
        ; Called if poll indicates that data can be written.
        (write object io_callback)
 
-       ; FIXME: We could put write_buffer inside the write callback,
+       ; NOTE: We could put write_buffer inside the write callback,
        ; but it seems simpler to keep it here, as it is needed by the
        ; prepare and write_close methods.
        (write_buffer object write_buffer)
@@ -176,7 +176,7 @@ void init_consuming_read(struct io_consuming_read *self,
        ; The port number here is always in host byte order
        (port . UINT32))) */
 
-/* Returned by listen */
+/* Returned by listen. And also by connect, so this is an improper name. */
 /* GABA:
    (class
      (name listen_value)
@@ -242,29 +242,26 @@ void io_run(struct io_backend *b);
 
 int blocking_read(int fd, struct read_handler *r);
 
-int get_inaddr(struct sockaddr_in	* addr,
-	       const char		* host,
-	       const char		* service,
-	       const char		* protocol);
+int get_portno(const char *service, const char *protocol);
 
-int get_portno(const char *s, const char *protocol);
+struct address_info *
+make_address_info_c(const char *host,
+		    const char *port,
+		    int def);
 
-int tcp_addr(struct sockaddr_in *sin,
-	     UINT32 length,
-	     UINT8 *addr,
-	     UINT32 port);
+struct address_info *
+make_address_info(struct lsh_string *host, 
+		  UINT32 port);
 
-struct address_info *make_address_info_c(const char *host,
-					 const char *port);
+struct address_info *
+sockaddr2info(size_t addr_len,
+	      struct sockaddr *addr);
 
-struct address_info *make_address_info(struct lsh_string *host, 
-				       UINT32 port);
-
-struct address_info *sockaddr2info(size_t addr_len UNUSED,
-				   struct sockaddr *addr);
-
-int address_info2sockaddr_in(struct sockaddr_in *sin,
-			     struct address_info *a);
+struct sockaddr *
+address_info2sockaddr(socklen_t *length,
+		      struct address_info *a,
+		      const int *preference,
+		      int lookup);
 
 /* Returns an exception, if anything went wrong */
 const struct exception *
@@ -287,17 +284,32 @@ make_exc_finish_read_handler(struct lsh_fd *fd,
 
 struct lsh_fd *
 io_connect(struct io_backend *b,
-	   struct sockaddr_in *remote,
-	   struct sockaddr_in *local,
+	   struct sockaddr *remote,
+	   socklen_t remote_length,
 	   struct command_continuation *c,
 	   struct exception_handler *e);
 
 struct lsh_fd *
 io_listen(struct io_backend *b,
-	  struct sockaddr_in *local,
+	  struct sockaddr *local,
+	  socklen_t length,
 	  struct io_callback *callback,
 	  struct exception_handler *e);
 
+struct lsh_fd *
+io_listen_local(struct io_backend *b,
+		struct lsh_string *directory,
+		struct lsh_string *name,
+		struct io_callback *callback,
+		struct exception_handler *e);
+
+struct lsh_fd *
+io_connect_local(struct io_backend *b,
+		 struct lsh_string *directory,
+		 struct lsh_string *name,
+		 struct command_continuation *c,
+		 struct exception_handler *e);
+
 struct io_callback *
 make_listen_callback(struct io_backend *backend,
 		     struct command_continuation *c,
