@@ -1,6 +1,6 @@
 /* io_commands.c
  *
- * $Id: io_commands.c,v 1.26 2000/02/20 19:14:10 nisse Exp $
+ * $Id: io_commands.c,v 1.32 2000/04/21 22:29:39 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -116,199 +116,254 @@ void do_io_read_fd(struct command *s,
 struct io_read_fd io_read_stdin
 = STATIC_IO_READ_FD(STDIN_FILENO);
 
-#if 0
-/* ;; GABA:
+
+/* GABA:
    (class
-     (name listen_command_callback)
-     (super fd_listen_callback)
+     (name remember_continuation)
+     (super command_continuation)
      (vars
-       (backend object io_backend)
-       (c object command_continuation)
-       (e object exception_handler)))
+       (resources object resource_list)
+       (up object command_continuation)))
 */
 
 static void
-do_listen_continue(struct fd_listen_callback *s, int fd,
-		   struct address_info *peer)
+do_remember_continuation(struct command_continuation *s,
+			 struct lsh_object *x)
 {
-  CAST(listen_command_callback, self, s);
-  NEW(listen_value, res);
+  CAST(remember_continuation, self, s);
+  CAST_SUBTYPE(resource, resource, x);
 
-  res->fd = make_lsh_fd(self->backend, fd, self->e);
-  res->peer = peer;
+  assert(resource);
+  REMEMBER_RESOURCE(self->resources, resource);
 
-  COMMAND_RETURN(self->c, res);
+  COMMAND_RETURN(self->up, resource);
 }
 
-static struct fd_listen_callback *
-make_listen_command_callback(struct io_backend *backend,
-			     struct command_continuation *c,
-			     struct exception_handler *e)
+struct command_continuation *
+make_remember_continuation(struct resource_list *resources,
+			   struct command_continuation *up)
 {
-  NEW(listen_command_callback, closure);
-  closure->backend = backend;
-  closure->c = c;
-  closure->e = e;
-  closure->super.f = do_listen_continue;
-  
-  return &closure->super;
+  NEW(remember_continuation, self);
+  self->super.c = do_remember_continuation;
+
+  self->resources = resources;
+  self->up = up;
+
+  return &self->super;
 }
-#endif
 
 static struct exception resolve_exception =
 STATIC_EXCEPTION(EXC_RESOLVE, "address could not be resolved");
 
+/* Used by both do_simple_listen and do_listen_connection. */
 static void
 do_listen(struct io_backend *backend,
 	  struct address_info *a,
+	  int lookup,
 	  struct resource_list *resources,
-	  struct command_continuation *c,
+	  /* Continuation if listen() succeeds. */
+	  struct command_continuation *listen_c,
+	  /* Continuation if accept() succeeds. */
+	  struct command_continuation *accept_c,
 	  struct exception_handler *e)
 {
-  /* FIXME: Add ipv6 support somewhere */
-  struct sockaddr_in sin;
-  struct lsh_fd *fd;
+  struct sockaddr *addr;
+  socklen_t addr_length;
   
-  if (!address_info2sockaddr_in(&sin, a))
+  struct lsh_fd *fd;
+
+  addr = address_info2sockaddr(&addr_length, a, NULL, lookup);
+  if (!addr)
     {
       EXCEPTION_RAISE(e, &resolve_exception);
       return;
     }
-  
-  fd = io_listen(backend, &sin,
-		 make_listen_callback(backend, c, e),
-		 e);
 
+  if (resources)
+    accept_c = make_remember_continuation(resources, accept_c);
+  
+  fd = io_listen(backend,
+		 addr, addr_length,
+		 make_listen_callback(backend, accept_c, e),
+		 e);
+  lsh_space_free(addr);
+  
   if (!fd)
     {
-      /* NOTE: Will never invoke the continuation. */
       EXCEPTION_RAISE(e, make_io_exception(EXC_IO_LISTEN,
 					   NULL, errno, NULL));
-      return;
     }
-  
-  if (resources)
-    REMEMBER_RESOURCE(resources, &fd->super);
+  else
+    {
+      if (resources)
+	REMEMBER_RESOURCE(resources, &fd->super);
+      if (listen_c)
+	COMMAND_RETURN(listen_c, fd);
+    }
 }
 
 /* A listen function taking three arguments:
  * (listen callback backend port).
  *
- * Suitable for handling forwarding requests. */
+ * Suitable for handling forwarding requests.
+ * NOTE: The calling function has to do all remembering of the fd:s. */
 
 /* GABA:
    (class
-     (name listen_connection)
+     (name listen_with_callback)
      (super command)
      (vars
        (callback object command)
        (backend object io_backend)))
-       ;; (connection object ssh_connection)))
 */
 
 static void
-do_listen_connection(struct command *s,
-		     struct lsh_object *x,
-		     struct command_continuation *c,
-		     struct exception_handler *e)
+do_listen_with_callback(struct command *s,
+			struct lsh_object *x,
+			struct command_continuation *c,
+			struct exception_handler *e)
 {
-  CAST(listen_connection, self, s);
+  CAST(listen_with_callback, self, s);
   CAST(address_info, address, x);
-  struct lsh_fd *fd;
-  
-  /* FIXME: Add ipv6 support somewhere */
-  struct sockaddr_in sin;
-  
-  if (!address_info2sockaddr_in(&sin, address))
-    {
-      EXCEPTION_RAISE(e, &resolve_exception);
-      return;
-    }
 
-  /* FIXME: Asyncronous dns lookups should go here */
-  fd = io_listen(self->backend, &sin,
-		 make_listen_callback
-		 (self->backend,
-		  make_apply(self->callback,
-			     &discard_continuation, e), e), e);
-  if (fd)
-    COMMAND_RETURN(c, fd);
-  else
-    EXCEPTION_RAISE(e,
-		    make_io_exception(EXC_IO_LISTEN, NULL,
-				      errno, NULL));
+  /* No dns lookups */
+  do_listen(self->backend, address, 0,
+	    NULL, /* FIXME: resources */
+	    c,
+	    make_apply(self->callback,
+		       &discard_continuation, e), e);
 }
 
-struct command *make_listen_command(struct command *callback,
-				    struct io_backend *backend)
+struct command *
+make_listen_with_callback(struct command *callback,
+			  struct io_backend *backend)
 {
-  NEW(listen_connection, self);
+  NEW(listen_with_callback, self);
   self->callback = callback;
   self->backend = backend;
 
-  self->super.call = do_listen_connection;
+  self->super.call = do_listen_with_callback;
 
   return &self->super;
 }
 
 static struct lsh_object *
-collect_listen(struct collect_info_2 *info,
-	       struct lsh_object *a,
-	       struct lsh_object *b)
+collect_listen_callback(struct collect_info_2 *info,
+			struct lsh_object *a,
+			struct lsh_object *b)
 {
   CAST_SUBTYPE(command, callback, a);
   CAST(io_backend, backend, b);
   assert(!info->next);
 
-  return &make_listen_command(callback, backend)->super;
+  return &make_listen_with_callback(callback, backend)->super;
 }
 
-static struct collect_info_2 collect_info_listen_2 =
-STATIC_COLLECT_2_FINAL(collect_listen);
+static struct collect_info_2 collect_info_listen_callback_2 =
+STATIC_COLLECT_2_FINAL(collect_listen_callback);
 
-struct collect_info_1 listen_command =
-STATIC_COLLECT_1(&collect_info_listen_2);
+struct collect_info_1 listen_with_callback =
+STATIC_COLLECT_1(&collect_info_listen_callback_2);
 
-#if 0
-/* FIXME: This could perhaps be merged with io_connect in io.c? */ 
-/* ;; GABA:
+
+/* A listen function taking three arguments:
+ * (listen backend connection port).
+ *
+ * Suitable for handling forwarding requests. Adds all fd:s to the
+ * connection's resource list automatically.
+ *
+ * NOTE: On second thought, this is not terribly useful, because
+ * accepted fd:s should usually be registered on a channels's resource
+ * list, not on the connection's. */
+
+/* GABA:
    (class
-     (name connect_command_callback)
-     (super fd_callback)
+     (name listen_with_connection)
+     (super command)
      (vars
-       (backend object io_backend)
-       (c object command_continuation)
-       (e object exception_handler)))
+       (connection object ssh_connection)
+       (backend object io_backend)))
 */
 
-/* FIXME: The new fd object should be added to the same resource list
- * as the old one. Perhaps the connection code in io.c should reuse
- * the fd object in some way? */
 static void
-do_connect_continue(struct fd_callback **s, int fd)
+do_listen_with_connection(struct command *s,
+			  struct lsh_object *x,
+			  struct command_continuation *c,
+			  struct exception_handler *e)
 {
-  CAST(connect_command_callback, self, *s);
+  CAST(listen_with_connection, self, s);
+  CAST(address_info, address, x);
 
-  assert(fd >= 0);
-
-  COMMAND_RETURN(self->c, make_lsh_fd(self->backend, fd, self->e));
+  /* No dns lookups */
+  do_listen(self->backend, address, 0,
+	    self->connection->resources,
+	    NULL,
+	    c, e);
 }
 
-static struct fd_callback *
-make_connect_command_callback(struct io_backend *backend,
-			      struct command_continuation *c,
-			      struct exception_handler *e)
+struct command *
+make_listen_with_connection(struct io_backend *backend,
+			    struct ssh_connection *connection)
 {
-  NEW(connect_command_callback, closure);
-  closure->backend = backend;
-  closure->c = c;
-  closure->e = e;
-  closure->super.f = do_connect_continue;
-  
-  return &closure->super;
-}
-#endif
+  NEW(listen_with_connection, self);
+  self->connection = connection;
+  self->backend = backend;
 
+  self->super.call = do_listen_with_connection;
+
+  return &self->super;
+}
+
+static struct lsh_object *
+collect_listen_connection(struct collect_info_2 *info,
+			  struct lsh_object *a,
+			  struct lsh_object *b)
+{
+  CAST(io_backend, backend, a);
+  CAST(ssh_connection, connection, b);
+  assert(!info->next);
+
+  return &make_listen_with_connection(backend, connection)->super;
+}
+
+static struct collect_info_2 collect_info_listen_connection_2 =
+STATIC_COLLECT_2_FINAL(collect_listen_connection);
+
+struct collect_info_1 listen_with_connection =
+STATIC_COLLECT_1(&collect_info_listen_connection_2);
+
+
+/* GABA:
+   (class
+     (name connect_continuation)
+     (super command_continuation)
+     (vars
+       (target object address_info)
+       (up object command_continuation)))
+*/
+
+static void
+do_connect_continuation(struct command_continuation *c,
+			struct lsh_object *x)
+{
+  CAST(connect_continuation, self, c);
+  CAST(lsh_fd, fd, x);
+
+  COMMAND_RETURN(self->up, make_listen_value(fd, self->target));
+}
+
+static struct command_continuation *
+make_connect_continuation(struct address_info *target,
+			  struct command_continuation *up)
+{
+  NEW(connect_continuation, self);
+  self->super.c = do_connect_continuation;
+  self->target = target;
+  self->up = up;
+
+  return &self->super;
+}
+     
 static void
 do_connect(struct io_backend *backend,
 	   struct address_info *a,
@@ -316,21 +371,26 @@ do_connect(struct io_backend *backend,
 	   struct command_continuation *c,
 	   struct exception_handler *e)
 {
-  /* FIXME: Add ipv6 support somewhere */
-  struct sockaddr_in sin;
+  struct sockaddr *addr;
+  socklen_t addr_length;
   struct lsh_fd *fd;
 
   /* Address must specify a host */
   assert(a->ip);
-  
-  if (!address_info2sockaddr_in(&sin, a))
+
+  /* Performs dns lookups */
+  addr = address_info2sockaddr(&addr_length, a, NULL, 1);
+  if (!addr)
     {
       EXCEPTION_RAISE(e, &resolve_exception);
       return;
     }
 
-  fd = io_connect(backend, &sin, NULL,
-		  c, e);
+  /* If the name is canonicalized in any way, we should pass the
+   * canonical name to make_connect_continuation() .*/
+  fd = io_connect(backend, addr, addr_length, 
+		  make_connect_continuation(a, c), e);
+  lsh_space_free(addr);
 
   if (!fd)
     {
@@ -371,8 +431,9 @@ do_connect_port(struct command *s,
 }
 
 
-struct command *make_connect_port(struct io_backend *backend,
-				  struct address_info *target)
+struct command *
+make_connect_port(struct io_backend *backend,
+		  struct address_info *target)
 {
   NEW(connect_port, self);
   self->super.call = do_connect_port;
@@ -426,7 +487,7 @@ do_simple_connect(struct command *s,
   CAST(simple_io_command, self, s);
   CAST(address_info, address, a);
 
-  do_connect(self->backend, address, self->resources, c, e);
+  do_connect(self->backend, address, NULL, c, e);
 }
 
 struct command *
@@ -436,14 +497,14 @@ make_simple_connect(struct io_backend *backend,
   NEW(simple_io_command, self);
   self->backend = backend;
   self->resources = resources;
-
+  
   self->super.call = do_simple_connect;
 
   return &self->super;
 }
 
 
-/* (connect port connection) */
+/* (connect connection port) */
 /* GABA:
    (class
      (name connect_connection)
@@ -465,7 +526,8 @@ do_connect_connection(struct command *s,
 		 make_simple_connect(self->backend, connection->resources));
 }
 
-struct command *make_connect_connection(struct io_backend *backend)
+struct command *
+make_connect_connection(struct io_backend *backend)
 {
   NEW(connect_connection, self);
   self->super.call = do_connect_connection;
@@ -484,9 +546,11 @@ do_simple_listen(struct command *s,
   CAST(simple_io_command, self, s);
   CAST(address_info, address, a);
 
-  do_listen(self->backend, address, self->resources, c, e);
+  /* Performs a dns lookup, if needed. */
+  do_listen(self->backend, address, 1, NULL, NULL, c, e);
 }
 
+/* FIXME: The resources argument is never used. */
 struct command *
 make_simple_listen(struct io_backend *backend,
 		   struct resource_list *resources)
@@ -494,7 +558,7 @@ make_simple_listen(struct io_backend *backend,
   NEW(simple_io_command, self);
   self->backend = backend;
   self->resources = resources;
-
+  
   self->super.call = do_simple_listen;
 
   return &self->super;
@@ -511,7 +575,7 @@ COMMAND_SIMPLE(io_log_peer_command)
   verbose("Accepting connection from %S, port %i\n",
 	  lv->peer->ip, lv->peer->port);
 
-  return &lv->fd->super.super;
+  return &lv->super;
 }
 
 
