@@ -1,6 +1,6 @@
 /* keyexchange.c
  *
- * $Id: keyexchange.c,v 1.61 2000/02/02 22:37:48 nisse Exp $ */
+ * $Id: keyexchange.c,v 1.62 2000/04/23 17:31:00 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -502,7 +502,7 @@ struct mac_instance *kex_make_mac(struct hash_instance *secret,
   key = kex_make_key(secret, algorithm->key_size,
 		     type, session_id);
 
-  mac = MAKE_MAC(algorithm, key->data);
+  mac = MAKE_MAC(algorithm, algorithm->key_size, key->data);
 
   lsh_string_free(key);
   return mac;
