@@ -2,7 +2,7 @@
  *
  * main proxy program.
  *
- * $Id: lsh_proxy.c,v 1.9 2000/04/02 19:33:27 nisse Exp $ */
+ * $Id: lsh_proxy.c,v 1.10 2000/04/19 00:40:40 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -158,7 +158,10 @@ make_lsh_proxy_options(struct io_backend *backend,
   self->backend = backend;
   self->style = SEXP_TRANSPORT;
   self->interface = NULL;
-  self->port = "ssh";
+
+  /* Default behaviour is to lookup the "ssh" service, and fall back
+   * to port 22 if that fails. */
+  self->port = NULL;
   /* FIXME: this should perhaps use sysconfdir */  
   self->hostkey = "/etc/lsh_host_key";
   self->local = NULL;
@@ -299,7 +302,11 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
       break;
       
     case ARGP_KEY_END:
-      self->local = make_address_info_c(self->interface, self->port);
+      if (self->port)
+	self->local = make_address_info_c(arg, self->port, 0);
+      else
+	self->local = make_address_info_c(arg, "ssh", 22);
+
       if (!self->local)
 	argp_error(state, "Invalid interface, port or service, %s:%s'.",
 		   self->interface ? self->interface : "ANY",
@@ -437,6 +444,7 @@ do_proxy_destination(struct command *s,
     COMMAND_RETURN(c, closure->options->destination);
   else
     {
+      /* FIXME: Why not use client_addr->peer? /nisse*/
       struct sockaddr_in sa;
       int salen = sizeof(sa);
 
@@ -455,7 +463,6 @@ do_proxy_destination(struct command *s,
 
 	  EXCEPTION_RAISE(e, ex);
 	}
-
     }
 }
 
