@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.36 2000/04/21 22:29:42 nisse Exp $
+ * $Id: server_session.c,v 1.37 2000/04/23 17:48:52 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -846,7 +846,7 @@ do_spawn_exec(struct channel_request *c,
   CAST(server_session, session, channel);
 
   UINT32 command_len;
-  UINT8 *command;
+  const UINT8 *command;
 
   struct lsh_string *command_line;
   
@@ -945,7 +945,7 @@ do_alloc_pty(struct channel_request *c UNUSED,
 	     struct exception_handler *e)
 {
   UINT32 width, height, width_p, height_p;
-  UINT8 *mode;
+  const UINT8 *mode;
   UINT32 mode_length;
   struct lsh_string *term = NULL;
 
