@@ -2,7 +2,7 @@
  *
  * An implementation of Ron Rivest's S-expressions, used in spki.
  *
- * $Id: sexp.h,v 1.25 1999/12/12 19:34:08 nisse Exp $ */
+ * $Id: sexp.h,v 1.26 2000/05/01 20:21:04 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -111,9 +111,8 @@ struct lsh_string *encode_base64(struct lsh_string *s,
 
 /* Creating sexps */
 
-/* FIXME: Rename this to sexp_s(d, c)? */
 /* Consumes its args (display may be NULL) */
-struct sexp *make_sexp_string(struct lsh_string *d, struct lsh_string *c);
+struct sexp *sexp_s(struct lsh_string *d, struct lsh_string *c);
 
 /* atom->sexp */
 struct sexp *sexp_a(const int a);
