@@ -2,7 +2,7 @@
  *
  * An implementation of SPKI certificate checking
  *
- * $Id: spki.c,v 1.16 2000/02/05 17:26:42 nisse Exp $ */
+ * $Id: spki.c,v 1.17 2000/05/01 20:32:47 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -102,7 +102,7 @@ make_ssh_hostkey_tag(struct address_info *host)
     }
 
   return sexp_l(2, sexp_z("ssh-hostkey"),
-		make_sexp_string(NULL, reversed),
+		sexp_s(NULL, reversed),
 		-1);
 }      
   
@@ -120,62 +120,6 @@ dsa_to_spki_public_key(struct dsa_public *dsa)
 		-1);
 }
 
-#if 0
-/* This functions expects only keyblobs of type ssh-dss. When we
- * accept spki keys, we must not accept ssh-dss keys, and vice versa.
- */
-struct sexp *keyblob2spki(struct lsh_string *keyblob)
-{
-  struct simple_buffer buffer;
-  UINT32 kbtype;
-  struct sexp *e = NULL;
-  
-  simple_buffer_init(&buffer, keyblob->length, keyblob->data);
-
-  if (parse_atom(&buffer, &kbtype))
-    switch(kbtype)
-      {
-      case ATOM_SSH_DSS:
-	{
-	  struct dsa_public dsa;
-	  init_dsa_public(&dsa);
-      
-	  if (parse_dsa_public(&buffer, &dsa)
-	      && parse_eod(&buffer))
-	    e = sexp_l(2, SA(PUBLIC_KEY),
-		       sexp_l(5, SA(DSA),
-			      /* FIXME: Should we use unsigned format? */
-			      sexp_l(2, SA(P), sexp_un(dsa.p), -1),
-			      sexp_l(2, SA(Q), sexp_un(dsa.q), -1),
-			      sexp_l(2, SA(G), sexp_un(dsa.g), -1),
-			      sexp_l(2, SA(Y), sexp_un(dsa.y), -1),
-			      -1),
-		       -1);
-	  else
-	    werror("Invalid dsa keyblob.");
-      
-	  dsa_public_free(&dsa);
-	  break;
-	}
-#if 0
-      case ATOM_SPKI:
-	e = sexp_parse_canonical(&buffer);
-	if (! (e && parse_eod(&buffer)))
-	  {
-	    werror("Invalid spki keyblob\n");
-	    e = NULL;
-	  }
-	break;
-#endif
-      default:
-	werror("Unknown keyblob format, only ssh-dss is supported\n");
-      }
-  else
-    werror("Invalid keyblob.\n");
-
-  return e;
-}
-#endif
 
 /* Returns 0 or an atom */
 int spki_get_type(struct sexp *e, struct sexp_iterator **res)
@@ -218,70 +162,6 @@ spki_check_type(struct sexp *e, int type, struct sexp_iterator **res)
   return 0;
 }
 
-#if 0
-/* NOTE: This function requires a particular order. */
-static struct sexp *dsa_private2public(struct sexp_iterator *i)
-{
-  struct sexp *p;
-  struct sexp *q;
-  struct sexp *g;
-  struct sexp *y;
-  struct sexp *x;
-
-  /* FIXME: Check length? */
-  if ( (p = sexp_assq(i, ATOM_P))
-       && (q = sexp_assq(i, ATOM_Q))
-       && (g = sexp_assq(i, ATOM_G))
-       && (y = sexp_assq(i, ATOM_Y))
-       && (x = sexp_assq(i, ATOM_X)))
-    return sexp_l(2, SA(PUBLIC_KEY),
-		  sexp_l(5, SA(DSA), p, q, g, y, -1), -1);
-  else
-    return NULL;
-      
-}
-
-
-static void
-do_spki_private2public(struct command *s UNUSED,
-		       struct lsh_object *a,
-		       struct command_continuation *c,
-		       struct exception_handler *e)
-{
-  CAST_SUBTYPE(sexp, key, a);
-  struct sexp_iterator *i;
-  struct sexp *expr;
-  struct sexp *pub;
-
-  if (!spki_check_type(key, ATOM_PRIVATE_KEY, &i))
-    {
-      SPKI_ERROR(e, "spki.c: Expected private key.", key);
-      return;
-    }
-
-  expr = SEXP_GET(i);
-  KILL(i);
-  switch (spki_get_type(expr, &i))
-    {
-    default:
-      SPKI_ERROR(e, "spki.c: Unknown key type (only dsa is supported).", key);
-      break;
-    case ATOM_DSA:
-      {
-	pub = dsa_private2public(i);
-	if (!pub)
-	  {
-	    SPKI_ERROR(e, "spki.c: Invalid DSA key.", key);
-	  }
-	else
-	  COMMAND_RETURN(c, pub);	
-      }
-    }
-}
-
-struct command spki_private2public
-= STATIC_COMMAND(do_spki_private2public);
-#endif
 
 COMMAND_SIMPLE(spki_signer2public)
 {
@@ -310,10 +190,10 @@ static void do_spki_hash(struct command *s,
   COMMAND_RETURN(c, sexp_l(3,
 			   SA(HASH),
 			   sexp_a(self->name),
-			   make_sexp_string(NULL,
-					    hash_string(self->algorithm,
-							sexp_format(o, SEXP_CANONICAL, 0),
-							1)),
+			   sexp_s(NULL,
+				  hash_string(self->algorithm,
+					      sexp_format(o, SEXP_CANONICAL, 0),
+					      1)),
 			   -1));
 }
 
@@ -348,49 +228,6 @@ const struct spki_hash spki_hash_sha1 =
        (algorithms object alist)))
 */
 
-#if 0
-/* FIXME: Perhaps this function should throw exceptions? */
-static struct keypair *
-parse_dsa_private_key(struct sexp_iterator *i
-		      /*, struct exception_handler *e */)
-{
-  struct dsa_signer *key = make_dsa_spki_signer(i, random);
-
-  if (key)
-    {
-      /* Test key */
-      mpz_t tmp;
-      int valid;
-      
-      mpz_init_set(tmp, key->public.g);
-      mpz_powm(tmp, tmp, key->a, key->public.p);
-      valid = !mpz_cmp(tmp, key->public.y);
-      mpz_clear(tmp);      
-
-      if (valid)
-	{
-	  struct lsh_string *public
-	    = ssh_format("%a%n%n%n%n", ATOM_SSH_DSS,
-			 key->public.p, key->public.q,
-			 key->public.g, key->public.y);
-
-	  debug("spki.c: parse_dsa_private_key: Using (public) key:\n"
-		"  p=%xn\n"
-		"  q=%xn\n"
-		"  g=%xn\n"
-		"  y=%xn\n",
-		key->public.p, key->public.q,
-		key->public.g, key->public.y);
-	  
-	  return make_keypair(ATOM_SSH_DSS, public, &key->super);
-	}
-      else
-	werror("spki.c: parse_dsa_private_key: Key doesn't work.");
-    }
-
-  return NULL;
-}
-#endif
 
 static void
 do_spki_sexp2signer(struct command *s, 
@@ -515,17 +352,6 @@ do_spki_sexp2keypair(struct command *s,
     } 
 }
 
-#if 0
-struct command *
-make_spki_parse_key(struct alist *algorithms)
-{
-  NEW(spki_parse_key, self);
-  
-  self->super.call = do_spki_parse_key;
-  self->algorithms = algorithms;
-  return &self->super;
-}
-#endif
 
 /* (parse algorithms sexp) -> one or more keypairs */
 COMMAND_SIMPLE(spki_sexp2keypair_command)
@@ -538,62 +364,6 @@ COMMAND_SIMPLE(spki_sexp2keypair_command)
   return &self->super.super;
 }
   
-#if 0
-/* ;; GABA:
-   (class
-     (name handle_key)
-     (super command_continuation)
-     (vars
-       (key simple "struct keypair **")))
-*/
-
-static void
-do_handle_key(struct command_continuation *c, struct lsh_object *r)
-{
-  CAST(handle_key, self, c);
-  CAST(keypair, key, r);
-
-  *self->key = key;
-}
-
-/* FIXME: We should really use some command instead. */
-/* NOTE: Reads only the first key from the file. */
-struct keypair *
-read_spki_key_file(const char *name,
-		   struct alist *algorithms,
-		   struct exception_handler *e)
-{
-  int fd = open(name, O_RDONLY);
-  if (fd < 0)
-    {
-      EXCEPTION_RAISE(e, make_io_exception(EXC_IO_OPEN_READ, NULL, errno, NULL));
-    }
-  else
-    {
-      struct keypair *keypair = NULL;
-      int res;
-
-      NEW(handle_key, handler);
-      handler->super.c = do_handle_key;
-      handler->key = &keypair;
-
-      e = make_report_exception_handler(EXC_SEXP, EXC_SEXP, "Reading keyfile: ",
-					e, HANDLER_CONTEXT);
-					
-      res = blocking_read(fd,
-			  make_read_sexp(SEXP_TRANSPORT, 0,
-					 make_apply(make_spki_parse_key(algorithms), 
-					            &handler->super, 
-					            e), 
-					 e));
-      close(fd);
-      KILL(handler);
-
-      return keypair;
-    }
-  return NULL;
-}
-#endif
 
 /* 5-tuples */
 
@@ -1303,187 +1073,3 @@ make_spki_context(struct alist *algorithms)
 
   return &self->super;
 }
-
-#if 0
-static void
-do_read_acls(struct command *s, 
-	     struct lsh_object *a,
-	     struct command_continuation *c,
-	     struct exception_handler *e)
-{
-  CAST(spki_command, self, s);
-  CAST_SUBTYPE(sexp, acl, a);
-
-  struct object_list *l = spki_read_acls(self->ctx, acl);
-
-  if (l)
-    COMMAND_RETURN(c, l);
-  else
-    SPKI_ERROR(e, "Invalid ACL list", acl);
-}
-#endif
-
-#if 0
-
-struct signer *
-spki_signer(struct sexp *e, struct alist *algorithms, int *t)
-{
-  struct sexp_iterator *i;
-  
-  if (spki_check_type(e, ATOM_PRIVATE_KEY, &i))
-    {
-      struct sexp *key = SEXP_GET(i);
-      struct sexp_iterator *inner;
-      int type = spki_get_type(key, &inner);
-      
-      if (type)
-	{
-	  CAST_SUBTYPE(spki_algorithm, algorithm, ALIST_GET(algorithms, type));
-
-	  if (algorithm)
-	    {
-	      *t = type;
-	      return SPKI_SIGNER(algorithm, i);
-	    }
-	}
-    }
-  return NULL;
-}
-
-struct verifier *
-spki_verifier(struct sexp *e, struct alist *algorithms, int *t)
-{
-  struct sexp_iterator *i;
-  
-  if (spki_check_type(e, ATOM_PRIVATE_KEY, &i))
-    {
-      struct sexp *key = SEXP_GET(i);
-      struct sexp_iterator *inner;
-      int type = spki_get_type(key, &inner);
-      
-      if (type)
-	{
-	  CAST_SUBTYPE(spki_algorithm, algorithm, ALIST_GET(algorithms, type));
-
-	  if (algorithm)
-	    {
-	      *t = type;
-	      return SPKI_VERIFIER(algorithm, i);
-	    }
-	}
-    }
-  return NULL;
-}
-
-
-/* ;; GABA:
-   (class
-     (name spki_dsa)
-     (super spki_algorithm)
-     (vars
-       (random object randomness)))
-*/
-
-static int do_spki_dsa_verify(struct verifier *s,
-			      UINT32 length,
-			      UINT8 *msg,
-			      UINT32 signature_length,
-			      UINT8 * signature_data)
-{
-  CAST(dsa_verifier, self, s);
-  struct simple_buffer buffer;
-  struct sexp *e;
-  mpz_t r, s;
-  
-  simple_buffer_init(&buffer, signature_length, signature_data);
-
-  if ( (e = sexp_parse_canonical(&buffer))
-       && parse_eod(buffer) )
-    {
-    }
-}
-    
-static verifier *
-make_spki_dsa_verifier(struct spki_algorithm *s UNUSED,
-		       struct sexp_iterator *i)
-{
-  NEW(dsa_verifier, res);
-  init_dsa_public(&res->public);
-
-  if (spki_dsa_init_public_key(&res->public, i))
-    {
-      res->super.verify = do_spki_dsa_verify;
-      return &res->super;
-    }
-  else
-    {
-      KILL(res);
-      return NULL;
-    }
-}
-
-static signer *
-make_spki_dsa_signer(struct spki_algorithm *s,
-		     struct sexp_iterator *i)
-{
-  NEW(dsa_signer, signer);
-  
-}
-#endif
-
-
-#if 0
-/* Encryption of private data.
- * Uses the format
- *
- * (password-encrypted LABEL sha1 ("3des-cbc" (iv #...#) (data #...#)))
- */
-/* ;; GABA:
-   (class
-     (name spki_password_encrypt)
-     (super command)
-     (vars
-       (label string)
-       (hash . UINT32)
-       (algorithm . UINT32)
-       (iv string)
-       (random object randomness)
-       (crypto object crypto_instance)))
-*/
-
-static void
-do_spki_encrypt(struct command *s,
-		struct lsh_object *a,
-		struct command_continuation *c,
-		struct exception_handler *e)
-{
-  CAST(spki_password_encrypt, self, s);
-  CAST_SUBTYPE(sexp, key, a);
-  UINT32 pad;
-  
-  string lsh_string *s = SEXP_FORMAT(key, SEXP_CANONICAL, 0);
-  pad = self->crypto->block_size - (s->length % self->crypto->block_size);
-
-  if (pad)
-    {
-      UINT8 *p;
-      s = ssh_format("%lfS%lr", s, pad, &p);
-      RANDOM(self->random, pad, p);
-    }
-
-  CRYPT(self->crypto, s->length, s->data, s->data);
-
-  COMMAND_RETURN(c,
-		 sexp_l(4,
-			SA(PASSWORD_ENCRYPTED),
-			make_sexp_string(lsh_string_dup(self->label), NULL),
-			sexp_a(self->hash),
-			sexp_l(3,
-			       sexp_a(self->algorithm),
-			       make_sexp_string(lsh_string_dup(self->iv), NULL),
-			       make_sexp_string(s, NULL),
-			       -1),
-			-1));
-}
-
-#endif
