@@ -1,6 +1,6 @@
 /* tcpforward_commands.c
  *
- * $Id: tcpforward_commands.c,v 1.23 2000/03/26 21:39:47 nisse Exp $
+ * $Id: tcpforward_commands.c,v 1.25 2000/04/21 21:33:16 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -83,11 +83,12 @@ do_tcpip_connect_io(struct command *ignored UNUSED,
 		    struct command_continuation *c,
 		    struct exception_handler *e UNUSED)
 {
-  CAST(lsh_fd, socket, x);
+  CAST(listen_value, lv, x);
 
-  assert(socket);
-
-  COMMAND_RETURN(c, make_tcpip_channel(socket, TCPIP_WINDOW_SIZE));
+  assert(lv);
+  assert(lv->fd);
+  
+  COMMAND_RETURN(c, make_tcpip_channel(lv->fd, TCPIP_WINDOW_SIZE));
 }
 
 struct command tcpip_connect_io = STATIC_COMMAND(do_tcpip_connect_io);
@@ -374,8 +375,6 @@ STATIC_COLLECT_1(&collect_info_remote_listen_2);
 /* GABA:
    (expr
      (name forward_local_port)
-     (globals
-       (listen LISTEN_COMMAND))
      (params
        (backend object io_backend)
        (local object address_info)
@@ -383,12 +382,13 @@ STATIC_COLLECT_1(&collect_info_remote_listen_2);
      (expr
        (lambda (connection)
          (connection_remember connection
-           (listen (lambda (peer)
-	             (tcpip_start_io
-		       (catch_channel_open 
-		         (open_direct_tcpip target peer) connection)))
-		   backend
-	           local)))))
+           (listen_callback
+	     (lambda (peer)
+	       (tcpip_start_io
+	         (catch_channel_open 
+		   (open_direct_tcpip target peer) connection)))
+	     backend
+	     local)))))
 */
 
 struct command *
@@ -526,8 +526,7 @@ STATIC_COLLECT_1(&install_tcpip_forward_info_2.super);
      (name tcpip_forward_hook)
      (globals
        (install "&install_tcpip_forward_handler.super.super.super")
-       (handler "&make_tcpip_forward_handler.super")
-       (listen LISTEN_COMMAND))
+       (handler "&make_tcpip_forward_handler.super"))
      (params
        (backend object io_backend))
      (expr
@@ -536,15 +535,16 @@ STATIC_COLLECT_1(&install_tcpip_forward_info_2.super);
          (install connection
 	   (handler (lambda (port)
 	     ;; Called when the client requests remote forwarding.
+	     ;; It should return the fd associated with the port.
 	     ;; NOTE: The caller, do_tcpip_forward_request, is responsible
-	     ;; for handling I/O exceptions.
-             (listen (lambda (peer)
-  		       ;; Called when someone connects to the
-  		       ;; forwarded port.
-  		       (tcpip_start_io
-			 (catch_channel_open 
-			   (open_forwarded_tcpip port peer) connection)))
-	             backend port)))))))
+	     ;; for handling I/O exceptions. and for remembering the port.
+	     (listen_callback (lambda (peer)
+  		  		;; Called when someone connects to the
+		  		;; forwarded port.
+		  		(tcpip_start_io
+		  		  (catch_channel_open 
+		  		    (open_forwarded_tcpip port peer) connection)))
+		  	      backend port))))))))
 */
 
 struct command *
